@@ -5,10 +5,10 @@
 #include <string>
 #include <vector>
 
-#include <pqxx/connection.h>
+#include <pqxx/connection>
 #include <pqxx/cursor.h>
-#include <pqxx/transaction.h>
-#include <pqxx/result.h>
+#include <pqxx/transaction>
+#include <pqxx/result>
 
 using namespace PGSTD;
 using namespace pqxx;
@@ -50,7 +50,7 @@ int main(int, char *argv[])
 {
   try
   {
-    const string Table = "events";
+    const string Table = "pqxxevents";
 
     connection C(argv[1]);
     transaction<serializable> T(C, "test45");
