@@ -1,8 +1,7 @@
 #include <iostream>
 #include <sstream>
 
-#include <pqxx/all.h>
-#include <pqxx/largeobject.h>
+#include <pqxx/pqxx>
 
 using namespace PGSTD;
 using namespace pqxx;
@@ -75,8 +74,8 @@ int main(int, char *argv[])
 
     largeobject Obj;
 
-    C.Perform(CreateLargeObject(Obj));
-    C.Perform(DeleteLargeObject(Obj));
+    C.perform(CreateLargeObject(Obj));
+    C.perform(DeleteLargeObject(Obj));
   }
   catch (const sql_error &e)
   {
